<?php

namespace Drp\SimpleCms\Http\Controllers\Admin;

use Drp\SimpleCms\Contracts\ContentFactory;
use Drp\SimpleCms\Contracts\Notifier;
use Drp\SimpleCms\Exceptions\CouldNotResetDraft;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Routing\Controller;

/**
 * Class ResetController
 * @package Drp\SimpleCms
 */
class ResetController extends Controller
{

    use AuthorizesRequests;

    /**
     * @var Notifier
     */
    private $notifier;
    /**
     * @var ContentFactory
     */
    private $contentFactory;

    /**
     * ResetController constructor.
     * @param ContentFactory $contentFactory
     * @param Notifier $notifier
     */
    public function __construct(ContentFactory $contentFactory, Notifier $notifier)
    {
        $this->notifier = $notifier;
        $this->contentFactory = $contentFactory;
    }

    /**
     * @param string $contentType
     * @param integer $versionId
     * @return \Illuminate\Http\RedirectResponse
     */
    public function __invoke($contentType, $versionId)
    {
        $content = $this->contentFactory->byTypeAndVersionId($contentType, $versionId);

        try {
            $this->authorize('publish', $content);
            $content->resetDraft();
            $this->notifier->success(trans('simpleCms::content.was-reset'));
        } catch (CouldNotResetDraft $e) {
            $this->notifier->error(trans('simpleCms::content.not-reset'));
        }
        return redirect()->back();
    }
}
