<?php

namespace Drp\SimpleCms\Test\Support\Fakes;

use Drp\SimpleCms\Content;

/**
 * Class TestContent
 */
class TestContent extends Content
{
    /**
     * The content label
     */
    const LABEL = 'Test content label';

    /**
     * The content key
     */
    const KEY = 'test-content';

    protected $fillable = ['title', 'status', 'content'];

    /**
     * @var
     */
    public $beforeCallback;

    /**
     * @var
     */
    public $afterCallback;

    /**
     * @var
     */
    public $requestCallback;

    /**
     * This function is called before a study is saved.
     *
     * @return \Closure|null
     * @SuppressWarnings("unused")
     */
    public function beforeSave()
    {
        parent::beforeSave();

        return $this->beforeCallback;
    }


    /**
     * This function is called after a study is saved.
     *
     * @return \Closure|null
     * @SuppressWarnings("unused")
     */
    public function afterSave()
    {
        parent::afterSave();

        return $this->afterCallback;
    }

    /**
     * Return the validation rules for publishing the study.
     *
     * @return mixed
     */
    public function getRules()
    {
        return [
            'title' => 'required'
        ];
    }

    /**
     * Return the validation messages for publishing the study.
     *
     * @return mixed
     */
    public function getMessages()
    {
        return [
            'title.required' => 'The title is required'
        ];
    }

    /**
     * Return a closure that will be called when submitting a ContentRequest.
     * This will allow the Managed class to perform its own action on the
     * request when being used in with the ContentManager.
     *
     * @return null|\Closure
     */
    public function getCallbackForUpdateRequest()
    {
        return $this->requestCallback;
    }

    /**
     * Return the url to view the content.
     *
     * @return mixed
     */
    public function frontEndUrl()
    {
        return route('test-content', [
            'title' => $this->title
        ]);
    }

}
