<?php

namespace Drp\SimpleCms\Test\Unit;

use Drp\SimpleCms\Contracts\Publishable;
use Drp\SimpleCms\Policies\PublishablePolicy;
use Drp\SimpleCms\Test\Support\Fakes\TestContent;
use Drp\SimpleCms\Test\Support\Fakes\TestUser;
use Drp\SimpleCms\Test\TestCase;
use Illuminate\Support\Facades\Gate;

/**
 * Class PublishablePolicyTest
 * @package Drp\SimpleCms\Test\Unit
 */
class PublishablePolicyTest extends TestCase
{

    /**
     * @test
     */
    public function it_determines_if_a_user_has_publish_access()
    {
        Gate::policy(TestContent::class, PublishablePolicy::class);

        $content = new TestContent();

        $user = new TestUser(false);
        $this->assertFalse($user->can('publish', $content));

        $user = new TestUser(true);
        $this->assertTrue($user->can('publish', $content));
    }

    /**
     * @test
     */
    public function it_determines_if_a_user_has_review_access()
    {
        Gate::policy(TestContent::class, PublishablePolicy::class);

        $content = new TestContent(['status' => Publishable::STATUS_PUBLISHED]);
        $user = new TestUser(false);
        $this->assertTrue($user->can('review', $content));

        $content = new TestContent(['status' => Publishable::STATUS_REVIEW]);
        $user = new TestUser(true);
        $this->assertTrue($user->can('review', $content));

        $user = new TestUser(false);
        $this->assertFalse($user->can('review', $content));
    }

    /**
     * @test
     */
    public function it_determines_if_a_user_has_delete_access()
    {
        Gate::policy(TestContent::class, PublishablePolicy::class);

        $content = new TestContent();

        $user = new TestUser(false);
        $this->assertFalse($user->can('delete', $content));

        $user = new TestUser(true);
        $this->assertTrue($user->can('delete', $content));
    }
}
